.. _API:

ACID API
========

.. currentmodule:: ACID_code

Core Classes
-------------

.. autosummary::
   :toctree: _api
   :nosignatures:

   Acid
   Result
   Data
   Config
   DataList
   LSD
   Profiles
   MCMC
   LineList
   MaskingLines

Utility Functions
------------------

.. autosummary::
   :toctree: _api
   :nosignatures:

   calc_deltav
   utils

Legacy ACID Functions
----------------------

These functions are retained for backwards compatibility with ACID v1.

.. autosummary::
   :toctree: _api
   :nosignatures:

   ACID
   ACID_HARPS
